@@ -1,8 +1,8 @@
-# Copyright 2009-2010 Ram Rachum. No part of this program may be used, copied
-# or distributed without explicit written permission from Ram Rachum.
+# Copyright 2009-2011 Ram Rachum.
+# This program is distributed under the LGPL2.1 license.
 
 '''
-This module defines the Settings class.
+This module defines the `Settings` class.
 
 See its documentation for more info.
 '''
