@@ -1,8 +1,8 @@
-# Copyright 2009-2010 Ram Rachum. No part of this program may be used, copied
-# or distributed without explicit written permission from Ram Rachum.
+# Copyright 2009-2011 Ram Rachum.
+# This program is distributed under the LGPL2.1 license.
 
 '''
-Defines the BitmapViewer class.
+Defines the `BitmapViewer` class.
 
 See its documentation for more info.
 '''
@@ -10,7 +10,7 @@ See its documentation for more info.
 import wx
 
 class BitmapViewer(wx.Panel):
-    '''Widget for viewing a bitmap. Similar to StaticBitmap.'''
+    '''Widget for viewing a bitmap. Similar to `StaticBitmap`.'''
     def __init__(self, *args, **kwargs):
         wx.Panel.__init__(self, *args, **kwargs)
         #self.SetBackgroundStyle(wx.BG_STYLE_CUSTOM)
@@ -21,8 +21,7 @@ class BitmapViewer(wx.Panel):
         '''EVT_PAINT handler.'''
         dc = wx.PaintDC(self)
         dc.DrawBitmap(self._bitmap, 0, 0)
-        dc.Destroy()
-        
+                
     def set_bitmap(self, bitmap):
         '''Set the bitmap that the viewer will display.'''
         self._bitmap = bitmap
